from typing import Dict

from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session

from app.db.session import get_db

router = APIRouter()


@router.get("/")
def health_check(
    db: Session = Depends(get_db),
) -> Dict:
    """
    Perform health check of the application.
    
    Checks:
    - Database connection
    """
    # Test database connection
    db_status = "healthy"
    try:
        db.execute("SELECT 1")
    except Exception:
        db_status = "unhealthy"
    
    return {
        "status": "healthy" if db_status == "healthy" else "unhealthy",
        "database": db_status
    }